import {Component, NgModule} from '@angular/core';
import {IgGridComponent} from "../../src/igniteui.angular2";
import {FormsModule} from '@angular/forms';
import {BrowserModule} from '@angular/platform-browser';
import {platformBrowserDynamic}    from '@angular/platform-browser-dynamic';

export class OverwriteStrategy {
    public static OVERWRITE = 0;
    public static DISCARD = 1;

    public static all = [
        {ID: OverwriteStrategy.OVERWRITE, Name: "Overwrite"},
        {ID: OverwriteStrategy.DISCARD, Name: "Discard"}
    ];
}


declare var jQuery: any;
@Component({
    selector: 'my-app',
    templateUrl: "./igGridTemplate.html"
})
export class AppComponent {
    private gridOptions: IgGrid;
    private id: string;
    private data: any = [];

    constructor() {
        this.addLotsOfProducts();

        this.id = 'grid1';

        this.gridOptions = {
            autoCommit: true,
            width: "100%",
            height: "400px",
            autoGenerateColumns: false,
            columns: [
                {key: "Duplicate", headerText: "Duplicate", width: "100px", dataType: "bool"},
                {key: "ProductID", headerText: "Product ID", width: "150px", dataType: "number"},
                {key: "ProductName", headerText: "Name", width: "250px", dataType: "string"},
                {
                    key: "OverwriteStrategy",
                    headerText: "OverwriteStrategy",
                    width: "150px",
                    dataType: "number",
                    formatter: (val: number) => {
                        return OverwriteStrategy.all.find((x) => x.ID === val).Name;
                    },
                    template: "{{if ${Duplicate}===true }}" + // TODO this breaks when other cell option is selected
                    "${OverwriteStrategy}" +
                    "{{/if}}"
                },
                {key: "QuantityPerUnit", headerText: "Quantity per unit", width: "250px", dataType: "string"},
                {
                    key: "UnitPrice",
                    headerText: "Unit Price",
                    width: "100px",
                    dataType: "number",
                    template: jQuery("#colTmpl").html()
                },
                {key: "Published", headerText: "Published", width: "100px", dataType: "bool", hidden: true},
                {
                    key: "Actions", headerText: "", width: "100px", dataType: "string", unbound: true,
                    template: "{{if ${Published} }}" +
                    "<input type='button' onclick='$(&#39;#locationsUnpublish&#39;).val(${ProductID});$(&#39;#locationsUnpublish&#39;).click()' value='Unpublish'/>" +
                    "{{else}}" +
                    "<input type='button' onclick='$(&#39;#locationsPublish&#39;).val(${ProductID});$(&#39;#locationsPublish&#39;).click()' value='Publish'/>" +
                    "{{/if}}"
                }
            ],
            primaryKey: "ProductID",
            features: [
                {
                    name: "Paging"
                },
                {
                    name: "Filtering"
                },
                {
                    name: "Sorting"
                },{
                    name: 'Updating',
                    enableAddRow: false,
                    enableDeleteRow: false,
                    editMode: "cell",
                    editCellStarting(evt: any, ui: any) {
                        if (ui.columnKey === "OverwriteStrategy") {
                            // Disable cell edit on "OverwriteStrategy" column when the record isn't a duplicate
                            return $("#grid1").igGrid("getCellValue", ui.rowID, "Duplicate");
                        } else {
                            // Disable cell edit on all other columns by default
                            return false;
                        }
                    },
                    columnSettings: [
                        {
                            columnKey: "OverwriteStrategy",
                            editorType: 'combo',
                            required: true,
                            editorOptions: {
                                mode: "dropdown",
                                dataSource: OverwriteStrategy.all,
                                textKey: "Name",
                                valueKey: "ID"
                            }
                        }
                    ]
                }
            ]
        };
    }

    addLotsOfProducts() {
        let products = [];
        for (let _i = 1; _i < 5000; _i++) {
            let newProduct = {};
            newProduct["ProductID"] = this.data.length + _i;
            newProduct["Duplicate"] = true;
            newProduct["OverwriteStrategy"] = _i%2;
            newProduct["ProductName"] = "product " + _i;
            newProduct["QuantityPerUnit"] = "4 kg pkg.";
            newProduct["UnitPrice"] = 34;
            newProduct["Published"] = _i%2;
            products.push(newProduct);
        }

        this.data = products;
    }

    public onPublish(productID: number) {
        let matchingProduct = this.data.filter(x => x.ProductID == productID)[0];
        matchingProduct.Published = true;
        $("#grid1").igGrid("dataBind");
    }

    public onUnpublish(productID: number) {
        let matchingProduct = this.data.filter(x => x.ProductID == productID)[0];
        matchingProduct.Published = false;
        $("#grid1").igGrid("dataBind");
    }
}

@NgModule({
    imports: [BrowserModule, FormsModule],
    declarations: [AppComponent, IgGridComponent],
    bootstrap: [AppComponent]
})
export class AppModule {
}

platformBrowserDynamic().bootstrapModule(AppModule);